@@ -1,4 +1,8 @@
-package WikiText::Sample`;
+package WikiText::Sample;
+use strict;
+use warnings;
+
+use base 'WikiText';
 
 1;
 
